/*
 * Created on Nov 3, 2003
 */
package org.ninjasoft.wmap;

import java.util.*;
import java.io.*;

/**
 * Container for all of the "auto" file directories.
 * 
 * @author enigma
 */
public class AutoList {
    public static String[] EXT = new String[] {
		".html",
        ".htm",
        ".php",
        ".php3",
        ".phps",
        ".asp",
        ".pl",
        ".jsp",
        ".txt",
        ".jpg",
        ".gif",
        ".png"
    };
    
    /** Vector to hold AutoTouple objects */
    private Vector list = new Vector();
    
    /** Hashtable to map an AutoTouple->group to a human-redable description */
    private Hashtable descriptions = new Hashtable();

    /**
     * Automatically load with the default property list
     * @throws IOException
     */
    public AutoList() throws IOException {
        load(this.getClass().getResourceAsStream("/org/ninjasoft/wmap/auto.properties"));
    }
    
    /**
     * Load with an explicitly given property list
     * @param in
     * @throws IOException
     */
    public AutoList(InputStream in) 
    throws IOException {
        load(in);
    }
    
    /**
     * Populate this object with the given property list
     * @param in
     * @throws IOException
     */
    public void load(InputStream in) 
    throws IOException {
        list = new Vector();
        descriptions = new Hashtable();
        Properties p = new Properties();
        p.load(in);
        for (Enumeration e = p.keys(); e.hasMoreElements(); ) {
            String key = (String) e.nextElement();
            String group = extractGroup(key);
            if (key.endsWith(".description")) {
                this.descriptions.put(group, p.getProperty(key, "No description"));
            }else{
                AutoTouple touple = new AutoTouple();
                touple.group = group;
                touple.directory = p.getProperty(key, "null");
                this.list.add(touple);
            }
        }
    }
    
    /**
     * Get an iterator that lets you walk through the AutoTouple list.
     * @return
     */
    public Iterator getIterator() {
        return this.list.iterator();
    }

    /**
     * Given a group name, return the description
     * @param group
     * @return
     */
    public String getDescription(String group) {
        String result = (String) descriptions.get(group);
        if (result == null)
            result = "No description";
        return result;
    }
    
    /**
     * Given a .property file key, extract the group
     * @param key
     * @return
     */
    private String extractGroup(String key) {
        int pos1 = key.indexOf('.');
        int pos2 = key.indexOf('.', pos1 + 1);
        if ((pos1 > 0) && (pos2 > pos1))
            return key.substring(pos1+1, pos2);
        return "unknown";
    }
    
    /**
     * Basic datastructure to hold a group/directory mapping
     */
    public class AutoTouple {
        public String directory = "";
        public String group = "";
    }
}
