package org.ninjasoft.wmap;

import gnu.getopt.LongOpt;
import gnu.getopt.Getopt;
/**
 * @author enigma
 */
public class Main {
    public static int help(String error) {
        if (error != null)
            System.err.println("ERROR: " + error + "\n\n");
        System.out.println("Command line help:");
        System.out.println(" Automatic Mode:");
        System.out.println("   java -jar wmap.jar --auto http://domain.com");
        System.out.println(" Manual Mode:");
        System.out.println("   java -jar wmap.jar --manual http://domain.com/dir/dir");
        System.out.println("Full command option summary:");
        System.out.println(" java -jar wmap.jar {flags} {base URL}");
        System.out.println("Flags:");
        System.out.println(" -a --auto                      Automatic mode");
        System.out.println(" -m --manual                    Manual mode");
        System.out.println(" -h --help                      This help text");
        System.out.println(" -d {seconds} --delay={seconds} In auto mode, delay between requests");
        return 1;
    }

    public static void main(String[] argv) {
        int c;
        boolean auto = false;
        boolean manual = false;
        int delay = 0;
        String baseUrl = "";
        // Define which options are available
        LongOpt[] longOpts = new LongOpt[4];
        longOpts[0] = new LongOpt("help", LongOpt.NO_ARGUMENT, null, 'h');
        longOpts[1] = new LongOpt("auto", LongOpt.NO_ARGUMENT, null, 'a');
        longOpts[2] = new LongOpt("manual", LongOpt.NO_ARGUMENT, null, 'm');
        longOpts[3] = new LongOpt("delay", LongOpt.REQUIRED_ARGUMENT, null, 'd');
        Getopt g = new Getopt("wmap", argv, "hamd:", longOpts);
        g.setOpterr(false);
        // Get command line options
        while ((c = g.getopt()) != -1) {
            switch(c) {
                case 'a':
                    auto = true;
                    break;
                case 'm':
                    manual = true;
                    break;
                case 'd':
                    try{ delay = Integer.parseInt(g.getOptarg());}catch(NumberFormatException nfe) {}
                    break;
                case 'h':
                    System.exit(help(null));
                case ':':
                    System.exit(help("Option " + (char)g.getOptopt() + " requires an argument"));
                case '?':
                    System.exit(help("Unknown option: " + (char) g.getOptopt()));
                default:
                    System.exit(help("Unknown option: " + (char) c));
            }
        }
        // Sanity check the input
        if (g.getOptind() >= argv.length)
            System.exit(help("Base URL must be supplied"));
        baseUrl = argv[g.getOptind()];
        if (!auto && !manual)
            System.exit(help("Either --auto or --manual need to be supplied"));
        if (auto && manual)
            System.exit(help("Only one of --auto and --manual can be supplied"));
        ConsoleUi ui = new ConsoleUi();
        ui.setDelay(delay);
        if (auto)
            ui.runAutomatic(baseUrl);
        else if (manual)
            ui.runManual(baseUrl);
        
        
    }
}
